@@ -422,28 +422,21 @@ class file_transport(transport):
 
 #-- class ---------------------------------------------------------------------
 
-class pulsar_dummy_transport(transport):
+class base_dummy_transport(transport):
     """
-    Class to replace Pulsar device with dummy device to support software stack testing without hardware.
-    The class implements all mandatory, required and Pulsar specific SCPI calls. Call reponses are
+    Class to replace device with dummy device to support software stack testing without hardware.
+    The class implements all mandatory and required SCPI calls. Call reponses are
     largely artifically constructed to be inline with the call's functionality (e.g. `*IDN?` returns valid,
-    but artificial IDN data.) To assist development, the Q1ASM assembler has been completely implemented.
-    Please have a look at the call's implentation to know what to expect from its response.
+    but artificial IDN data.)
     """
 
     #--------------------------------------------------------------------------
-    def __init__(self, acq_scope_cfg_format: str, sequencer_cfg_format: str) -> None:
+    def __init__(self) -> None:
         """
-        Create Pulsar dummy transport class.
+        Create base dummy transport class.
 
         Parameters
         ----------
-        acq_scope_cfg_format : str
-            Configuration format based on `struct.pack <https://docs.python.org/3/library/struct.html>`_ format
-            used to calculate scope acquisition configuration transaction size.
-        sequencer_cfg_format : str
-            Configuration format based on `struct.pack <https://docs.python.org/3/library/struct.html>`_ format
-            used to calculate sequencer configuration transaction size.
 
         Returns
         ----------
@@ -456,61 +449,17 @@ class pulsar_dummy_transport(transport):
         self._data_out               = 0
         self._bin_out                = None
         self._system_error           = []
-        self._asm_status             = False
-        self._asm_log                = ''
-        self._acq_scope_cfg          = {}
-        self._sequencer_cfg          = {}
-        self._acq_scope_cfg_bin_size = struct.calcsize(acq_scope_cfg_format)
-        self._sequencer_cfg_bin_size = struct.calcsize(sequencer_cfg_format)
-        self._awg_waveforms          = {}
-        self._acq_weights            = {}
-        self._acq_acquisitions       = {}
-        self._cmds                   = {"*CMDS?":                                     self._get_cmds,
-                                        "*IDN?":                                      self._get_idn,
-                                        "*RST":                                       self._reset,
-                                        "SYSTem:ERRor:NEXT?":                         self._get_system_error,
-                                        "SYSTem:ERRor:COUNt?":                        self._get_system_error_cnt,
-                                        "STATus:ASSEMbler:SUCCess?":                  self._get_assembler_status,
-                                        "STATus:ASSEMbler:LOG?":                      self._get_assembler_log,
-                                        "ACQ:SCOpe:CONFiguration":                    self._set_acq_scope_config,
-                                        "ACQ:SCOpe:CONFiguration?":                   self._get_acq_scope_config,
-                                        "SEQuencer#:PROGram":                         self._set_sequencer_program,
-                                        "SEQuencer#:CONFiguration":                   self._set_sequencer_config,
-                                        "SEQuencer#:CONFiguration?":                  self._get_sequencer_config,
-                                        "SEQuencer#:AWG:WLISt:WAVeform:NEW":          self._add_awg_waveform,
-                                        "SEQuencer#:AWG:WLISt:WAVeform:DELete":       self._del_awg_waveform,
-                                        "SEQuencer#:AWG:WLISt:WAVeform:DATA":         self._set_awg_waveform_data,
-                                        "SEQuencer#:AWG:WLISt:WAVeform:DATA?":        self._get_awg_waveform_data,
-                                        "SEQuencer#:AWG:WLISt:WAVeform:INDex":        self._set_awg_waveform_index,
-                                        "SEQuencer#:AWG:WLISt:WAVeform:INDex?":       self._get_awg_waveform_index,
-                                        "SEQuencer#:AWG:WLISt:WAVeform:LENGth?":      self._get_awg_waveform_length,
-                                        "SEQuencer#:AWG:WLISt:WAVeform:NAME?":        self._get_awg_waveform_name,
-                                        "SEQuencer#:AWG:WLISt:SIZE?":                 self._get_num_awg_waveforms,
-                                        "SEQuencer#:AWG:WLISt?":                      self._get_awg_waveforms,
-                                        "SEQuencer#:ACQ:WLISt:WEIght:NEW":            self._add_acq_weight,
-                                        "SEQuencer#:ACQ:WLISt:WEIght:DELete":         self._del_acq_weight,
-                                        "SEQuencer#:ACQ:WLISt:WEIght:DATA":           self._set_acq_weight_data,
-                                        "SEQuencer#:ACQ:WLISt:WEIght:DATA?":          self._get_acq_weight_data,
-                                        "SEQuencer#:ACQ:WLISt:WEIght:INDex":          self._set_acq_weight_index,
-                                        "SEQuencer#:ACQ:WLISt:WEIght:INDex?":         self._get_acq_weight_index,
-                                        "SEQuencer#:ACQ:WLISt:WEIght:LENGth?":        self._get_acq_weight_length,
-                                        "SEQuencer#:ACQ:WLISt:WEIght:NAME?":          self._get_acq_weight_name,
-                                        "SEQuencer#:ACQ:WLISt:SIZE?":                 self._get_num_acq_weights,
-                                        "SEQuencer#:ACQ:WLISt?":                      self._get_acq_weights,
-                                        "SEQuencer#:ACQ:ALISt:ACQuisition:NEW":       self._add_acq_acquisition,
-                                        "SEQuencer#:ACQ:ALISt:ACQuisition:DELete":    self._del_acq_acquisition,
-                                        "SEQuencer#:ACQ:ALISt:ACQuisition:DATA":      self._set_acq_acquisition_data,
-                                        "SEQuencer#:ACQ:ALISt:ACQuisition:DATA?":     self._get_acq_acquisition_data,
-                                        "SEQuencer#:ACQ:ALISt:ACQuisition:INDex":     self._set_acq_acquisition_index,
-                                        "SEQuencer#:ACQ:ALISt:ACQuisition:INDex?":    self._get_acq_acquisition_index,
-                                        "SEQuencer#:ACQ:ALISt:ACQuisition:NUM_BINS?": self._get_acq_acquisition_num_bins,
-                                        "SEQuencer#:ACQ:ALISt:SIZE?":                 self._get_num_acq_acquisitions,
-                                        "SEQuencer#:ACQ:ALISt?":                      self._get_acq_acquisitions}
+        self._cmds                   = {"*CMDS?":              self._get_cmds,
+                                        "*IDN?":               self._get_idn,
+                                        "*RST":                self._reset,
+                                        "SYSTem:ERRor:NEXT?":  self._get_system_error,
+                                        "SYSTem:ERRor:COUNt?": self._get_system_error_cnt
+                                       }
 
     #--------------------------------------------------------------------------
     def close(self) -> None:
         """
-        Close and resets Pulsar dummy transport class.
+        Close and resets base dummy transport class.
 
         Parameters
         ----------
@@ -522,12 +471,15 @@ class pulsar_dummy_transport(transport):
         ----------
         """
 
-        self.__init__('', '')
+        self._cmd_hist     = []
+        self._data_out     = 0
+        self._bin_out      = None
+        self._system_error = []
 
     #--------------------------------------------------------------------------
     def write(self, cmd_str: str) -> None:
         """
-        Write command to Pulsar dummy. Stores command in command history (see :func:`ieee488_2.transport.pulsar_dummy_transport.get_cmd_hist`).
+        Write command to dummy. Stores command in command history (see :func:`ieee488_2.transport.base_dummy_transport.get_cmd_hist`).
 
         Parameters
         ----------
@@ -546,7 +498,7 @@ class pulsar_dummy_transport(transport):
     #--------------------------------------------------------------------------
     def write_binary(self, data: bytes) -> None:
         """
-        Write binary data to Pulsar dummy. Stores command in command history (see :func:`ieee488_2.transport.pulsar_dummy_transport.get_cmd_hist`).
+        Write binary data to dummy. Stores command in command history (see :func:`ieee488_2.transport.base_dummy_transport.get_cmd_hist`).
 
         Parameters
         ----------
@@ -568,7 +520,7 @@ class pulsar_dummy_transport(transport):
     #--------------------------------------------------------------------------
     def read_binary(self, size: int) -> bytes:
         """
-        Read binary data from Pulsar dummy.
+        Read binary data from dummy.
 
         Parameters
         ----------
@@ -591,7 +543,7 @@ class pulsar_dummy_transport(transport):
     #--------------------------------------------------------------------------
     def readline(self) -> str:
         """
-        Read data from Pulsar dummy.
+        Read data from dummy.
 
         Parameters
         ----------
@@ -612,7 +564,7 @@ class pulsar_dummy_transport(transport):
         """
         Parse command and split it into command, parameters and arguments. Then execute associated command method found in command dictionary.
         If the command is not in the command dictionary, respond with the default response ('0'). The command is stored in the command history
-        (see :func:`ieee488_2.transport.pulsar_dummy_transport.get_cmd_hist`).
+        (see :func:`ieee488_2.transport.base_dummy_transport.get_cmd_hist`).
 
         Parameters
         ----------
@@ -664,10 +616,11 @@ class pulsar_dummy_transport(transport):
         header_b = str(len(data)).encode()
         header_a = ('#' + str(len(header_b))).encode()
         if end_of_line:
-            return header_a + header_b + data + '\r\n'.encode()
+            out = header_a + header_b + data + '\r\n'.encode()
         else:
-            return header_a + header_b + data
-        
+            out = header_a + header_b + data
+
+        return out
 
     #--------------------------------------------------------------------------
     @staticmethod
@@ -763,16 +716,16 @@ class pulsar_dummy_transport(transport):
         """
 
         self._data_out = "Qblox," + \
-                         "Pulsar Dummy," + \
+                         "Qblox Dummy," + \
                          "whatever," + \
-                         "fwVersion=0.0.0 fwBuild=28/11/1967-00:00:00 fwHash=0xDEADBEAF fwDirty=0 " + \
+                         "fwVersion=0.0.0 fwBuild=28/11/1967-00:00missing:00 fwHash=0xDEADBEAF fwDirty=0 " + \
                          "kmodVersion=0.0.0 kmodBuild=15/07/1943-00:00:00 kmodHash=0x0D15EA5E kmodDirty=0 " + \
                          "swVersion=0.0.0 swBuild=11/05/1924-00:00:00 swHash=0xBEEFBABE swDirty=0"
 
     #--------------------------------------------------------------------------
     def _reset(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
         """
-        Reset Pulsar dummy.
+        Reset dummy.
 
         Parameters
         ----------
@@ -842,6 +795,91 @@ class pulsar_dummy_transport(transport):
 
         self._data_out = str(len(self._system_error))
 
+#-- class ---------------------------------------------------------------------
+
+class pulsar_dummy_transport(base_dummy_transport):
+    """
+    Class to replace Pulsar device with dummy device to support software stack testing without hardware.
+    The class implements all mandatory, required and Pulsar specific SCPI calls. Call reponses are
+    largely artifically constructed to be inline with the call's functionality (e.g. `*IDN?` returns valid,
+    but artificial IDN data.) To assist development, the Q1ASM assembler has been completely implemented.
+    Please have a look at the call's implentation to know what to expect from its response.
+    """
+
+    #--------------------------------------------------------------------------
+    def __init__(self, acq_scope_cfg_format: str, sequencer_cfg_format: str) -> None:
+        """
+        Create Pulsar dummy transport class.
+
+        Parameters
+        ----------
+        acq_scope_cfg_format : str
+            Configuration format based on `struct.pack <https://docs.python.org/3/library/struct.html>`_ format
+            used to calculate scope acquisition configuration transaction size.
+        sequencer_cfg_format : str
+            Configuration format based on `struct.pack <https://docs.python.org/3/library/struct.html>`_ format
+            used to calculate sequencer configuration transaction size.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+
+        super(pulsar_dummy_transport, self).__init__()
+
+        self._asm_status             = False
+        self._asm_log                = ''
+        self._acq_scope_cfg          = {}
+        self._sequencer_cfg          = {}
+        self._acq_scope_cfg_bin_size = struct.calcsize(acq_scope_cfg_format)
+        self._sequencer_cfg_bin_size = struct.calcsize(sequencer_cfg_format)
+        self._awg_waveforms          = {}
+        self._acq_weights            = {}
+        self._acq_acquisitions       = {}
+        self._channelmap             = {}
+
+        self._cmds["STATus:ASSEMbler:SUCCess?"]                  = self._get_assembler_status
+        self._cmds["STATus:ASSEMbler:LOG?"]                      = self._get_assembler_log
+        self._cmds["ACQ:SCOpe:CONFiguration"]                    = self._set_acq_scope_config
+        self._cmds["ACQ:SCOpe:CONFiguration?"]                   = self._get_acq_scope_config
+        self._cmds["SEQuencer#:PROGram"]                         = self._set_sequencer_program
+        self._cmds["SEQuencer#:CONFiguration"]                   = self._set_sequencer_config
+        self._cmds["SEQuencer#:CONFiguration?"]                  = self._get_sequencer_config
+        self._cmds["SEQuencer#:AWG:WLISt:WAVeform:NEW"]          = self._add_awg_waveform
+        self._cmds["SEQuencer#:AWG:WLISt:WAVeform:DELete"]       = self._del_awg_waveform
+        self._cmds["SEQuencer#:AWG:WLISt:WAVeform:DATA"]         = self._set_awg_waveform_data
+        self._cmds["SEQuencer#:AWG:WLISt:WAVeform:DATA?"]        = self._get_awg_waveform_data
+        self._cmds["SEQuencer#:AWG:WLISt:WAVeform:INDex"]        = self._set_awg_waveform_index
+        self._cmds["SEQuencer#:AWG:WLISt:WAVeform:INDex?"]       = self._get_awg_waveform_index
+        self._cmds["SEQuencer#:AWG:WLISt:WAVeform:LENGth?"]      = self._get_awg_waveform_length
+        self._cmds["SEQuencer#:AWG:WLISt:WAVeform:NAME?"]        = self._get_awg_waveform_name
+        self._cmds["SEQuencer#:AWG:WLISt:SIZE?"]                 = self._get_num_awg_waveforms
+        self._cmds["SEQuencer#:AWG:WLISt?"]                      = self._get_awg_waveforms
+        self._cmds["SEQuencer#:ACQ:WLISt:WEIght:NEW"]            = self._add_acq_weight
+        self._cmds["SEQuencer#:ACQ:WLISt:WEIght:DELete"]         = self._del_acq_weight
+        self._cmds["SEQuencer#:ACQ:WLISt:WEIght:DATA"]           = self._set_acq_weight_data
+        self._cmds["SEQuencer#:ACQ:WLISt:WEIght:DATA?"]          = self._get_acq_weight_data
+        self._cmds["SEQuencer#:ACQ:WLISt:WEIght:INDex"]          = self._set_acq_weight_index
+        self._cmds["SEQuencer#:ACQ:WLISt:WEIght:INDex?"]         = self._get_acq_weight_index
+        self._cmds["SEQuencer#:ACQ:WLISt:WEIght:LENGth?"]        = self._get_acq_weight_length
+        self._cmds["SEQuencer#:ACQ:WLISt:WEIght:NAME?"]          = self._get_acq_weight_name
+        self._cmds["SEQuencer#:ACQ:WLISt:SIZE?"]                 = self._get_num_acq_weights
+        self._cmds["SEQuencer#:ACQ:WLISt?"]                      = self._get_acq_weights
+        self._cmds["SEQuencer#:ACQ:ALISt:ACQuisition:NEW"]       = self._add_acq_acquisition
+        self._cmds["SEQuencer#:ACQ:ALISt:ACQuisition:DELete"]    = self._del_acq_acquisition
+        self._cmds["SEQuencer#:ACQ:ALISt:ACQuisition:DATA"]      = self._set_acq_acquisition_data
+        self._cmds["SEQuencer#:ACQ:ALISt:ACQuisition:DATA?"]     = self._get_acq_acquisition_data
+        self._cmds["SEQuencer#:ACQ:ALISt:ACQuisition:INDex"]     = self._set_acq_acquisition_index
+        self._cmds["SEQuencer#:ACQ:ALISt:ACQuisition:INDex?"]    = self._get_acq_acquisition_index
+        self._cmds["SEQuencer#:ACQ:ALISt:ACQuisition:NUM_BINS?"] = self._get_acq_acquisition_num_bins
+        self._cmds["SEQuencer#:ACQ:ALISt:SIZE?"]                 = self._get_num_acq_acquisitions
+        self._cmds["SEQuencer#:ACQ:ALISt?"]                      = self._get_acq_acquisitions
+        self._cmds["SEQuencer#:CHANnelmap"]                      = self._set_channelmap
+        self._cmds["SEQuencer#:CHANnelmap?"]                     = self._get_channelmap
+
+
     #--------------------------------------------------------------------------
     def _get_assembler_status(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
         """
@@ -1346,7 +1384,6 @@ class pulsar_dummy_transport(transport):
                 self._bin_out += self._encode_bin(name.encode(), False)
                 self._bin_out += self._encode_bin(struct.pack('I', int(self._awg_waveforms[cmd_params[0]][name]["index"])), False)
                 self._bin_out += self._encode_bin(self._awg_waveforms[cmd_params[0]][name]["wave"], end_of_line)
-            return
         else:
             self._bin_out = self._encode_bin(struct.pack('I', 0), True)
 
@@ -1660,7 +1697,6 @@ class pulsar_dummy_transport(transport):
                 self._bin_out += self._encode_bin(name.encode(), False)
                 self._bin_out += self._encode_bin(struct.pack('I', int(self._acq_weights[cmd_params[0]][name]["index"])), False)
                 self._bin_out += self._encode_bin(self._acq_weights[cmd_params[0]][name]["wave"], end_of_line)
-            return
         else:
             self._bin_out = self._encode_bin(struct.pack('I', 0), True)
 
@@ -1686,7 +1722,7 @@ class pulsar_dummy_transport(transport):
         Raises
         ----------
         """
-        
+
         if cmd_params[0] in self._acq_acquisitions:
             if cmd_args[0] in self._acq_acquisitions[cmd_params[0]]:
                 self._system_error.append("Acquisition {} already in acquisition list.".format(cmd_args[0]))
@@ -1767,7 +1803,7 @@ class pulsar_dummy_transport(transport):
                 return
         self._system_error.append("Acquisition {} does not exist in acquisition list.".format(cmd_args[0]))
 
-    #--------------------------------------------------------------------------    
+    #--------------------------------------------------------------------------
     def _get_acq_acquisition_data(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
         """
         Get acquisition data of a single acquisition from the specified sequencer's acquisition list.
@@ -1976,6 +2012,113 @@ class pulsar_dummy_transport(transport):
                     bins.append(self._acq_acquisitions[cmd_params[0]][name]["acq"]["bins"][bin_it]["thres"])
                     bins.append(self._acq_acquisitions[cmd_params[0]][name]["acq"]["bins"][bin_it]["avg_cnt"])
                 self._bin_out += self._encode_bin(struct.pack('='+num_bins*'QqqLL', *bins), end_of_line)
-            return
         else:
             self._bin_out = self._encode_bin(struct.pack('I', 0), True)
+
+    # --------------------------------------------------------------------------
+    def _set_channelmap(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
+        """
+        Sets the channelmap list.
+
+        Parameters
+        ----------
+        cmd_params : list
+            Command parameters indicated by '#' in the command.
+        cmd_args : list
+            Command arguments.
+        bin_in : bytes
+            Binary input data.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+        sequencer_idx: str = cmd_params[0]
+        channel_map_bin = self._decode_bin(bin_in)
+        channel_map = list(
+            struct.unpack("I" * int(len(channel_map_bin) / 4), channel_map_bin)
+        )
+        self._channelmap[sequencer_idx] = channel_map
+
+    # --------------------------------------------------------------------------
+    def _get_channelmap(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
+        """
+        Gets the channelmap list. If not set previously, returns an empty list.
+
+        Parameters
+        ----------
+        cmd_params : list
+            Command parameters indicated by '#' in the command.
+        cmd_args : list
+            Command arguments.
+        bin_in : bytes
+            Binary input data.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+        channel_map = list()
+        if cmd_params[0] in self._channelmap:
+            channel_map = self._channelmap[cmd_params[0]]
+        channel_map_packed = struct.pack("I" * len(channel_map), *channel_map)
+        self._bin_out = self._encode_bin(channel_map_packed)
+
+#-- class ---------------------------------------------------------------------
+
+class cluster_dummy_transport(base_dummy_transport):
+    """
+    Class to replace Cluster device with dummy device to support software stack testing without hardware.
+    The class implements all mandatory, required and Cluster specific SCPI calls. Call reponses are
+    largely artifically constructed to be inline with the call's functionality (e.g. `*IDN?` returns valid,
+    but artificial IDN data.) To assist development, the Q1ASM assembler has been completely implemented.
+    Please have a look at the call's implentation to know what to expect from its response.
+    """
+
+    #--------------------------------------------------------------------------
+    def __init__(self) -> None:
+        """
+        Create Cluster dummy transport class.
+
+        Parameters
+        ----------
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+
+        super(cluster_dummy_transport, self).__init__()
+
+        self._mod_present = (1<<20)-1
+
+        self._cmds["BP:MODules?"] = self._get_modules_present
+
+    #--------------------------------------------------------------------------
+    def _get_modules_present(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
+        """
+        Get modules present in the Cluster.
+
+        Parameters
+        ----------
+        cmd_params : list
+            Command parameters indicated by '#' in the command.
+        cmd_args : list
+            Command arguments.
+        bin_in : bytes
+            Binary input data.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+
+        self._data_out = self._mod_present
