@@ -64,7 +64,7 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
         Instrument.__init__(self, name)
 
         #Set instrument parameters
-        self._num_sequencers = 1
+        self._num_sequencers = 6
 
         #Set JSON schema to validate JSON file with
         self._wave_and_prog_json_schema = {"title":       "Sequencer waveforms and program container",
@@ -135,21 +135,9 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
 
         if self._get_lo_hw_present():
             self.add_parameter(
-                "lo0_freq",
-                label      = "Local Oscillator 0 frequency.",
-                docstring  = "Sets/gets the local oscillator 0 output frequency.",
-                unit       = 'Hz',
-                vals       = vals.Numbers(2e9, 18e9),
-                set_parser = int,
-                get_parser = int,
-                set_cmd    = self._set_lo_freq_0,
-                get_cmd    = self._get_lo_freq_0
-            )
-
-            self.add_parameter(
-                "lo1_freq",
-                label      = "Local Oscillator 1 frequency.",
-                docstring  = "Sets/gets the local oscillator 1 output frequency.",
+                "out0_in0_lo_freq",
+                label      = "Local Oscillator frequency for output 0 and input 0.",
+                docstring  = "Sets/gets the local oscillator frequency for output 0 and input 0.",
                 unit       = 'Hz',
                 vals       = vals.Numbers(2e9, 18e9),
                 set_parser = int,
@@ -158,29 +146,79 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
                 get_cmd    = self._get_lo_freq_1
             )
 
-        self.add_parameter(
-            "in0_amp_gain",
-            label      = "Input 0 amplifier gain.",
-            docstring  = "Sets/gets input 0 amplifier gain in a range of -6dB to 26dB with a resolution of 1dB per step.",
-            unit       = 'dB',
-            vals       = vals.Numbers(-6, 26),
-            set_parser = int,
-            get_parser = int,
-            set_cmd    = self._set_in_amp_gain_0,
-            get_cmd    = self._get_in_amp_gain_0
-        )
+        if not self._get_lo_hw_present():
+            self.add_parameter(
+                "in0_gain",
+                label      = "Input 0 gain.",
+                docstring  = "Sets/gets input 0 gain in a range of -6dB to 26dB with a resolution of 1dB per step.",
+                unit       = 'dB',
+                vals       = vals.Numbers(-6, 26),
+                set_parser = int,
+                get_parser = int,
+                set_cmd    = self._set_in_amp_gain_0,
+                get_cmd    = self._get_in_amp_gain_0
+            )
 
-        self.add_parameter(
-            "in1_amp_gain",
-            label      = "Input 1 amplifier gain.",
-            docstring  = "Sets/gets input 1 amplifier gain in a range of -6dB to 26dB with a resolution of 1dB per step.",
-            unit       = 'dB',
-            vals       = vals.Numbers(-6, 26),
-            set_parser = int,
-            get_parser = int,
-            set_cmd    = self._set_in_amp_gain_1,
-            get_cmd    = self._get_in_amp_gain_1
-        )
+            self.add_parameter(
+                "in1_gain",
+                label      = "Input 1 gain.",
+                docstring  = "Sets/gets input 1 gain in a range of -6dB to 26dB with a resolution of 1dB per step.",
+                unit       = 'dB',
+                vals       = vals.Numbers(-6, 26),
+                set_parser = int,
+                get_parser = int,
+                set_cmd    = self._set_in_amp_gain_1,
+                get_cmd    = self._get_in_amp_gain_1
+            )
+
+        if self._get_lo_hw_present():
+            self.add_parameter(
+                "out0_offset_path0",
+                label      = "Output 0 offset for path 0.",
+                docstring  = "Sets/gets output 0 offset for path 0.",
+                unit       = 'mV',
+                vals       = vals.Numbers(-84.0, 73.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_out_amp_offset_0,
+                get_cmd    = self._get_out_amp_offset_0
+            )
+
+            self.add_parameter(
+                "out0_offset_path1",
+                label      = "Output 0 offset for path 1.",
+                docstring  = "Sets/gets output 0 offset for path 1.",
+                unit       = 'mV',
+                vals       = vals.Numbers(-84.0, 73.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_out_amp_offset_1,
+                get_cmd    = self._get_out_amp_offset_1
+            )
+        else:
+            self.add_parameter(
+                "out0_offset",
+                label      = "Output 0 offset.",
+                docstring  = "Sets/gets output 0 offset.",
+                unit       = 'V',
+                vals       = vals.Numbers(-1.0, 1.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_dac_offset_0,
+                get_cmd    = self._get_dac_offset_0
+            )
+
+            self.add_parameter(
+                "out1_offset",
+                label      = "Output 1 offset.",
+                docstring  = "Sets/gets output 1 offset.",
+                unit       = 'V',
+                vals       = vals.Numbers(-1.0, 1.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = self._set_dac_offset_1,
+                get_cmd    = self._get_dac_offset_1
+            )
 
         #--Scope acquisition settings------------------------------------------
         self.add_parameter(
@@ -195,7 +233,7 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
             set_cmd     = partial(self._set_acq_scope_config_val, "trig_mode_acq_path_0"),
             get_cmd     = partial(self._get_acq_scope_config_val, "trig_mode_acq_path_0")
         )
-        
+
         self.add_parameter(
             "scope_acq_trigger_mode_path1",
             label       = "Scope acquisition trigger mode for input path 0.",
@@ -232,7 +270,7 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
             set_cmd    = partial(self._set_acq_scope_config_val, "trig_lvl_acq_path_1_float"),
             get_cmd    = partial(self._get_acq_scope_config_val, "trig_lvl_acq_path_1_float")
         )
-        
+
         self.add_parameter(
             "scope_acq_sequencer_select",
             label       = "Scope acquisition sequencer select for when using sequencer trigger mode.",
@@ -241,8 +279,8 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
             vals        = vals.Numbers(0, self._num_sequencers),
             set_parser  = int,
             get_parser  = int,
-            set_cmd     = partial(self._set_acq_scope_config_val, "trig_mode_acq_path_0"),
-            get_cmd     = partial(self._get_acq_scope_config_val, "trig_mode_acq_path_0")
+            set_cmd     = partial(self._set_acq_scope_config_val, "sel_acq"),
+            get_cmd     = partial(self._get_acq_scope_config_val, "sel_acq")
         )
 
         self.add_parameter(
@@ -270,6 +308,29 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
 
         for seq_idx in range(0, self._num_sequencers):
             #--Sequencer settings----------------------------------------------
+            self.add_parameter(
+                "sequencer{}_channel_map_path0_out0_en".format(seq_idx),
+                label      = "Sequencer {} path 0 output 0 enable.".format(seq_idx),
+                docstring  = "Sets/gets sequencer {} channel map enable of path 0 to output 0.".format(seq_idx),
+                unit       = '',
+                vals       = vals.Bool(),
+                set_parser = bool,
+                get_parser = bool,
+                set_cmd    = partial(self._set_sequencer_channel_map, seq_idx, 0),
+                get_cmd    = partial(self._get_sequencer_channel_map, seq_idx, 0)
+            )
+
+            self.add_parameter(
+                "sequencer{}_channel_map_path1_out1_en".format(seq_idx),
+                label      = "Sequencer {} path 1 output 1 enable.".format(seq_idx),
+                docstring  = "Sets/gets sequencer {} channel map enable of path 1 to output 1.".format(seq_idx),
+                unit       = '',
+                vals       = vals.Bool(),
+                set_parser = bool,
+                get_parser = bool,
+                set_cmd    = partial(self._set_sequencer_channel_map, seq_idx, 1),
+                get_cmd    = partial(self._get_sequencer_channel_map, seq_idx, 1)
+            )
             self.add_parameter(
                 "sequencer{}_sync_en".format(seq_idx),
                 label      = "Sequencer {} synchronization enable which enables party-line synchronization.".format(seq_idx),
@@ -463,6 +524,30 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
                 get_cmd    = partial(self._get_sequencer_config_val, seq_idx, "offset_awg_path_1_float")
             )
 
+            self.add_parameter(
+                "sequencer{}_mixer_corr_phase_offset_degree".format(seq_idx),
+                label      = "Sequencer {} mixer phase imbalance correction for AWG; applied to AWG path 1 relative to AWG path 0 and measured in degrees.".format(seq_idx),
+                docstring  = "Sets/gets sequencer {} mixer phase imbalance correction for AWG; applied to AWG path 1 relative to AWG path 0 and measured in degrees".format(seq_idx),
+                unit       = '',
+                vals       = vals.Numbers(-45.0, 45.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = partial(self._set_sequencer_config_val, seq_idx, "mixer_corr_phase_offset_degree_float"),
+                get_cmd    = partial(self._get_sequencer_config_val, seq_idx, "mixer_corr_phase_offset_degree_float")
+            )
+
+            self.add_parameter(
+                "sequencer{}_mixer_corr_gain_ratio".format(seq_idx),
+                label      = "Sequencer {} mixer gain imbalance correction for AWG; equal to AWG path 1 amplitude divided by AWG path 0 amplitude.".format(seq_idx),
+                docstring  = "Sets/gets sequencer {} mixer gain imbalance correction for AWG; equal to AWG path 1 amplitude divided by AWG path 0 amplitude.".format(seq_idx),
+                unit       = '',
+                vals       = vals.Numbers(0.5, 2.0),
+                set_parser = float,
+                get_parser = float,
+                set_cmd    = partial(self._set_sequencer_config_val, seq_idx, "mixer_corr_gain_ratio_float"),
+                get_cmd    = partial(self._get_sequencer_config_val, seq_idx, "mixer_corr_gain_ratio_float")
+            )
+
             self.add_parameter(
                 "sequencer{}_mod_en_awg".format(seq_idx),
                 label      = "Sequencer {} modulation enable for AWG.".format(seq_idx),
@@ -510,7 +595,7 @@ class pulsar_qrm_qcodes(pulsar_qrm_ifc, Instrument):
                 vals       = vals.Numbers(0, 360),
                 set_parser = float,
                 get_parser = float,
-                set_cmd    = partial(self._set_sequencer_config_rotation_matrix, seq_idx), 
+                set_cmd    = partial(self._set_sequencer_config_rotation_matrix, seq_idx),
                 get_cmd    = partial(self._get_sequencer_config_rotation_matrix, seq_idx)
             )
 
