@@ -22,9 +22,9 @@ def get_build_info():
     ----------
     """
 
-    return {"version": "0.4.0",
-            "date":    "21/07/2021-18:27:27",
-            "hash":    "0x70593743",
+    return {"version": "0.5.1",
+            "date":    "07/10/2021-13:58:39",
+            "hash":    "0x0AE2580C",
             "dirty":   False}
 
 
